/*
 * tlv.h
 * WiFi DataElements TLV genaration functions header file.
 *
 * Copyright (C) 2020-2022 IOPSYS Software Solutions AB. All rights reserved.
 *
 * See LICENSE file for license related information.
 */

#ifndef DECOLLECTOR_TLV_H
#define DECOLLECTOR_TLV_H

size_t sizeof_cac_cap_opclass(const struct cac_cap_opclass *o);
size_t sizeof_cac_cap_cac(const struct cac_cap_cac *cap);
size_t sizeof_cac_cap_radio(const struct cac_cap_radio *cap_radio);
size_t sizeof_channel_scan_capability_opclass(const struct channel_scan_capability_opclass *o);
size_t sizeof_channel_scan_capability_radio(const struct channel_scan_capability_radio *cap_radio);


int decollector_gen_aladdr(struct decollector_private *priv, struct cmdu_buff *cmdu);
int decollector_gen_searched_role(struct decollector_private *priv,
		struct cmdu_buff *cmdu, uint8_t role);
int decollector_gen_autoconfig_band(struct decollector_private *priv,
		struct cmdu_buff *cmdu, uint8_t band);
int decollector_gen_supported_service(struct decollector_private *priv,
		struct cmdu_buff *cmdu, uint8_t service);
int decollector_gen_searched_service(struct decollector_private *priv,
		struct cmdu_buff *cmdu, uint8_t service);
int decollector_gen_map_profile(struct decollector_private *priv,
		struct cmdu_buff *cmdu, uint8_t profile);
int decollector_gen_ap_radio_identifier(struct decollector_private *priv,
		struct cmdu_buff *cmdu, uint8_t *radio_id);
int decollector_gen_ap_metric_query(struct decollector_private *priv,
		struct cmdu_buff *cmdu, int num_bss, uint8_t *bsslist);
int decollector_gen_channel_scan_request(struct decollector_private *priv,
		struct cmdu_buff *cmdu, struct wifi_network_device *dev);


int decollector_gen_ap_oper_bss(struct wifi_network_device *dev,
		struct cmdu_buff *cmdu);
int decollector_gen_assoc_client(struct wifi_network_device *dev,
		struct cmdu_buff *cmdu);
int decollector_gen_ap_cap(struct wifi_network_device *dev, struct cmdu_buff *cmdu);
int decollector_gen_ap_radio_basic_cap(struct wifi_network_device *dev,
		struct cmdu_buff *cmdu, int radio_index);
int decollector_gen_ap_ht_cap(struct wifi_network_device *dev,
		struct cmdu_buff *cmdu, int radio_index);
int decollector_gen_ap_vht_cap(struct wifi_network_device *dev,
		struct cmdu_buff *cmdu, int radio_index);
int decollector_gen_ap_he_cap(struct wifi_network_device *dev,
		struct cmdu_buff *cmdu, int radio_index);
int decollector_gen_channel_scan_capability(struct wifi_network_device *dev,
		struct cmdu_buff *cmdu);
int decollector_gen_cac_cap(struct wifi_network_device *dev, struct cmdu_buff *cmdu);
int decollector_gen_profile2_ap_cap(struct wifi_network_device *dev,
		struct cmdu_buff *cmdu);
int decollector_gen_metric_collection_int(struct wifi_network_device *dev,
		struct cmdu_buff *cmdu);
int decollector_gen_radio_metrics(struct wifi_network_device *dev,
		struct cmdu_buff *cmdu, int radio_index);
int decollector_gen_ap_metrics(struct wifi_network_device *own,
		struct cmdu_buff *cmdu, int radio_index, int bss_index);
int decollector_gen_ap_ext_metrics(struct wifi_network_device *dev,
		struct cmdu_buff *cmdu, int radio_index, int bss_index);
int decollector_gen_assoc_sta_traffic_stats(struct wifi_network_device *dev,
		struct cmdu_buff *cmdu, int radio_index,
		int bss_index, int sta_index);
int decollector_gen_assoc_sta_link_metrics(struct wifi_network_device *dev,
		struct cmdu_buff *cmdu, int radio_index,
		int bss_index, int sta_index);
int decollector_gen_assoc_sta_ext_link_metric(struct wifi_network_device *dev,
		struct cmdu_buff *cmdu, int radio_index,
		int bss_index, int sta_index);
int decollector_gen_bsta_radio_cap(struct wifi_network_device *dev,
		struct cmdu_buff *cmdu, int radio_index);
int decollector_gen_oper_channel_report(struct wifi_network_device *dev,
		struct cmdu_buff *cmud, int radio_index);
int decollector_gen_channel_scan_result(struct wifi_network_device *dev,
		struct cmdu_buff *cmdu, int radio_index,
		int opclass_index, int channel_index);
int decollector_gen_client_assoc_event(struct decollector_private *priv,
		struct cmdu_buff *cmdu, uint8_t *sta_mac,
		const char *event, uint8_t *bssid);
int decollector_gen_sta_mac(struct decollector_private *priv,
		struct cmdu_buff *cmdu, uint8_t *sta);
int decollector_gen_reason_code(struct decollector_private *priv,
		struct cmdu_buff *cmdu, int reason_code);
int decollector_gen_disassoc_stats(struct decollector_private *priv, struct cmdu_buff *cmdu,
		uint8_t *sta, struct wifi_disassoc_event *ev);
int decollector_gen_client_info(struct decollector_private *priv,
		struct cmdu_buff *cmdu, uint8_t *sta, uint8_t *bssid);
int decollector_gen_client_cap_report(struct decollector_private *priv,
		struct cmdu_buff *cmdu, uint8_t result,
		struct wifi_assoc_frame *assoc_frame);
int decollector_gen_vendor_specific(struct wifi_network_device *dev,
		struct cmdu_buff *cmdu);


#endif /* DECOLLECTOR_TLV_H */

